@@ -50,4 +50,12 @@ GnomeVFSMimeApplication *eel_mime_check_for_duplicates                  (const c
 GnomeVFSMimeApplication *eel_mime_check_for_desktop_duplicates          (const char *mime_type,
 									 const char *desktop_file);
 
+typedef struct {
+	char *mime_type;
+	char *description;
+} EelMimeTypeInfo;
+
+GList *eel_mime_get_availible_mime_types (void);
+void   eel_mime_type_info_free           (EelMimeTypeInfo *info);
+
 #endif
